# torch-ac-simple
A simpler way to train and evaluate your Minigrid agents. This project is built on top of [torch-ac](), thus all training/eval functionality are similar. For further information on how to configure you model refer to [torch-ac's documentation]() and this [playground project]() similarly built upon `torch-ac`.

# Installation
```bash
pip install torch_ac_simple
```

# How To Use
## Create Agent
```py
import torch_ac_simple
```
